import "../../style/basket_court.css"
import { useRef } from "react"
import CourtPlayer from "./CourtPlayer"
import { Player } from "../../tactic/Player"

export interface BasketCourtProps {
    players: Player[]
    onPlayerRemove: (p: Player) => void
    onPlayerChange: (p: Player) => void
    courtImage: string,
}

export function BasketCourt({
    players,
    onPlayerRemove,
    onPlayerChange,
    courtImage
}: BasketCourtProps) {
    const divRef = useRef<HTMLDivElement>(null)

    return (
        <div id="court-container" ref={divRef} style={{ position: "relative" }}>
            <img src={courtImage} alt={"court"} id="court-svg"/>
            {players.map((player) => {
                return (
                    <CourtPlayer
                        key={player.team + player.role}
                        player={player}
                        onChange={onPlayerChange}
                        onRemove={() => onPlayerRemove(player)}
                        parentRef={divRef}
                    />
                )
            })}
        </div>
    )
}
